% File: movieBurgers.m
% From Appendix 6 - 'Animating Simulation Results', of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
%
% Code to generate Burgers equation Movie
% Run after pde_1_main.m from Chapter 5.
% Generates animation movies from Matlab workspace data
% User should select from choices presented in dialog boxes!
%
clc
% Get screen size
  scrsz=get(0,'ScreenSize');
%
% Define required position for figure
  rect=[20 (scrsz(4)/2-100) scrsz(3)/2 scrsz(4)/2];
%
% Create figure at required position
  h1=figure('Position',rect);
  set(h1,'DoubleBuffer','on');
%
% Define required dimensions of image to be saved within
% figure
  frameRect=[0 0 scrsz(3)/2 scrsz(4)/2];
%
% Set up animation parameters
  [mm nn]=size(u);
  frameSteps=1; % Plot image every frameSteps
  nframes=ceil(mm/frameSteps); % Number of frames in the
% movie
  Frames=moviein(nframes); % Initialize the matrix
% 'Frames'
  avi_fName='BurgersEqn_01.avi'; % Movie file name
  if exist(avi_fName,'file') ~= 0
    fprintf('File: %s, already exists!\n\n', avi_fName);
    fileMsg=sprintf('File: %s, already exists - Choose to:', ...
      avi_fName);
    namChoice=menu(fileMsg,'Overwrite','New Name');
    if namChoice==1
      delete(avi_fName);
    else
      newName=inputdlg('Movie file name:','File Name Request', ...
      1,{avi_fName});
      if isempty(newName{1})
        delete(avi_fName);
      else
        [pathstr,name,ext]=fileparts(newName{1});
        if strcmp('.avi',ext)==0
          avi_fName=strcat(newName{1},'.avi');
        else
          avi_fName=newName{1};
        end
      end
      if exist(avi_fName,'file')
        delete(avi_fName);
      end
    end
  end
%
% avi movie parameters
  fps=5; % Frames per second
  aviMov= VideoWriter(avi_fName);
  aviMov.FrameRate=fps;
  open(aviMov);
%
% Movie calculations
  % plotType=1; % Set plot type, 1=2D, 2=3D
  plotType=menu('Choose Plot Type:','2D', ...
  '2D+Analytical Solution','3D');
  qq=1; % Set frame skip counter
  frameCount=0; % Initialise frame counter
  u1=0.1*ones(mm,n);
  for it=1:mm
    qq=qq-1;
    if qq==0,
      frameCount=frameCount+1;
      if plotType==1 || plotType==2
%
%       2D Plot
        if plotType==1
          h2=plot(x,u(it,:));
        else
          plot(x,u(it,:),'o',x,u_anal(it,:),'-')
          legend('Numerical solution', ...
            'Analytical solution', ...
            'location', 'southwest');
        end
        hold on
        xlabel('x')
        ylabel('u(x,t)')
        set(gca,'XLim',[0 1],'YLim',[0 1]);
        title('Burgers equation');
        grid on
      else
%
% Update u1 for each frame
      if it <= frameSteps % First frame
        u1(it,:)=u(it,:);
      else % Subsequent frames
        u1(it-frameSteps:it,:)=u(it-frameSteps:it,:);
      end
      surfl(x,t,u1,'light');
      shading interp
      title('Burgers equation');
      set(get(gca,'XLabel'),'String','space, x')
      set(get(gca,'YLabel'),'String','time, t')
      set(get(gca,'ZLabel'),'String',...
        'dependent variable, u(t,x)')
      set(gca,'XLim',[0 1],'YLim',[0 1],'ZLim', [0 1]);
      axis tight
      view(40,29);
      colormap('cool'); % set color map
    end
    Frames=getframe; % Create image in Frames array
    writeVideo(aviMov,Frames); % Add frame to avi movie file
    disp([' Plot number: ', num2str(frameCount), ' created']);
    end
    qq=frameSteps;
  end
  close(aviMov); % Close avi movie file
  fprintf('\navi movie created in file: %s \n', avi_fName);
%
% Print image to file
% print -dpng -r300 BurgersEqnPlot



