% File: movieLaplace.m
% From Appendix 6 - 'Animating Simulation Results', of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
%
% Run after pde_1_main.m in Chapter 11
% Generates a sequence of images from Matlab workspace data
% populated by a previous simulation run that can be assembled into a gif
% file - see page 458.
  delta=1/(nx-1);
  [x,y,z]=meshgrid(0:delta:1,0:delta:1,0:delta:1);
  figure(1); clf; hold on; axis equal; axis on;
%
% Set suitable color map
  colormap(jet(16));
%
% Set Shading
  shading faceted
  for it=1:nout
%
% Set 3D data at step 'it'
    w(:,:,:)=u(it,:,:,:);
%
% Define slice planes to include in plot
    xslice=[0.1,.5,0.9]; yslice=[0]; zslice=[0,1];
%
% Create slice image
    slice(x,y,z,w,xslice,yslice,zslice)
    xlabel('x');ylabel('y');zlabel('z');
    tStr=sprintf('Step No: %d',it);
    title(tStr);
    caxis([0,1]);
%
% Include colorbar - scale
    colorbar
%
% Set viewpoint
    view(-161,8);
%
% Set file name with numeric increment
    file=sprintf('Movie_frame%d.png', 1000+it);
    disp(sprintf('Saving to %s', file));
%
% Save image file
    print('-dpng','-zbuffer','-r100',file);
  end