% File: movieSchrodinger.m
% From Appendix 6 - 'Animating Simulation Results', of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
%
% Code to generate Schrodingers equation movie
% Run after pde_1_main.m from Chapter 6. To get good plot
% increase number of time steps.
% Generates animation movies from Matlab workspace data
% User should select from choices presented in dialog boxes!
%
  avi_fName='SchrodingerEqn_01.avi'; % Movie file name
  if exist(avi_fName) ~= 0
    fprintf('File: %s, already exists!\n\n', avi_fName);
    fileMsg=sprintf('File: %s, already exists - Choose to:', ...
      avi_fName);
    namChoice=menu(fileMsg,'Overwrite','New Name');
    if namChoice==1
      delete(avi_fName);
    else
      newName=inputdlg('Movie file name:', ...
        'File Name Request',1,{avi_fName});
      if isempty(newName{1})
        delete(avi_fName);
      else
        [pathstr,name,ext,versn]=fileparts(newName{1});
        if strcmp('.avi',ext)==0
          avi_fName=strcat(newName{1},'.avi');
        else
          avi_fName=newName{1};
        end
      end
      if exist(avi_fName)
        delete(avi_fName);
      end
    end
  end
%
% Set Plot Type: 1=2D, 2=2D + Analytic, 3=3D
  plotType=menu([{'Cubic Schrodinger Equation Solution.'}, ...
            {'Choose Plot Type:'}],'2D', ...
            '2D+Analytical Solution','3D');
%
% Get screen size
  scrsz=get(0,'ScreenSize');
%
% Define required position for figure
  rect=[20 (scrsz(4)/2-100) scrsz(3)/2 scrsz(4)/2];
%
% Create figure at required position
  h1=figure('Position',rect);
  set(h1,'DoubleBuffer','on');
%
% Define required dimensions of image to be saved
% within figure
  frameRect=[0 0 scrsz(3)/2 scrsz(4)/2];
%
% avi movie parameters
  fps=5; % Frames per second
  aviMov= VideoWriter(avi_fName);
  aviMov.FrameRate=fps;
  open(aviMov);
%
% Movie calculations
% Plot image every frameStep
  if plotType==1 | plotType==2
    frameStep=1;
  else
    frameStep=1;
  end
  qq=1; % Set frame skip counter
%
% Set up animation parameters
[mm nn]=size(v2w2);
nframes=ceil(mm/frameStep); % Number of frames in the movie
Frames=moviein(nframes); % Initialize the matrix 'Frames'
frameCount=0; % Initialise frame counter
u1=zeros(mm,n);
  for it=1:mm
    qq=qq-1;
    if qq==0
      frameCount=frameCount+1;
      if plotType==1 | plotType==2
      %
      % 2D Plot
        if plotType==1
          h2=plot(x,v2w2(it,:));
          title('CSE - numerical solution.');
        else
          h2=plot(x,v2w2(it,:),'o',x,v2w2_anal(it,:),'-');
          title('CSE: o - numerical; solid - analytical.');
        end
        xlabel('x')
        ylabel('u(x,t)')
        set(gca,'XLim',[-10 40],'YLim', [0 2]);
        grid on
      else
      %
      % Update u1 for each frame
      if it <= frameStep % First frame
        u1(it,:)=v2w2(it,:);
      else % Subsequent frames
        u1(it-frameStep:it,:)=v2w2(it-frameStep:it,:);
      end
      h2=surfl(x,t,u1, 'light');
      shading interp
      title('Cubic Schrodinger Equation');
      set(get(gca,'XLabel'),'String','space, x')
      set(get(gca,'YLabel'),'String','time, t')
      set(get(gca,'ZLabel'),'String','dependent variable,u(t,x)')
      set(gca,'XLim',[-10 40],'YLim',[0 30],'ZLim', [0 2]);
      axis tight
      view(-10,45)
      colormap('cool'); % set color map
    end
    Frames=getframe; % Create image in Frames array
    writeVideo(aviMov,Frames); % Add frame to avi movie file
    fprintf('\n Plot number: %d created', frameCount);
    end
    qq=frameStep; % Reset qq
  end
  close(aviMov); % Close avi movie file
  fprintf('\navi movie created in file: %s \n', avi_fName);
%
% Print image to file
% print -dpng -r300 SchrodingersEqnPlot