% File: movieSphericalDiffusion.m (rev. 1 - October 2012)
% From Appendix 6 - 'Animating Simulation Results', of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
%==========================================================
% To be run after pde_2_main.m code from Chapter 14
% Generates a sequence of images from Matlab workspace data
% populated by a previous simulation run. Images can then be
% used to create an animated gif file.
%==========================================================
% Set Up Plotting Vars
r1=linspace(-r0,r0,2*nr-1);
th1=linspace(0,2*pi,2*nth-1);
%
% Create mesh for single quadrant image
[R1, Theta1]=meshgrid(r, th);
%
% Create mesh for four-quadrant mesh
[R2, Theta2]=meshgrid(r1, th1);
%
% Convert meshes to Cartesian form
[X1,Z1]=pol2cart(Theta1,R1);
[X2,Z2]=pol2cart(Theta2,R2);
plotType = 2; % Set plot type: 1=single-quadrant,
              %                2=four-quadrant
%
% Plot dependant variable, u(r,theta) over one quadrant
% at t=tf
figure();
for it=1:1:nout
  %
  % Create 2D matrix of simulation output data at t(it)
  U0(:,:)=u(it,:,:);
  %
  % Convert results data to be suitable for use with the
  % meshgrid using cubic interpolation
  U1=interp2(th,r,U0,Theta1,R1,'cubic');
  if plotType == 1
    %
    % Create plot from single quadrant data
    surf(Z1, X1, U1); hold on;
  else
    %
    % Create four-quadrant data set from single quadrant data
    % by flipping (vertical/horizontal) and shifting operations
    U2=quadJoin(U1);
    %
    % Create plot from four-quadrant data
    surf(Z2, X2, U2); hold on;
  end
  shading interp
  colormap jet
  axis tight; axis square;
  colorbar; caxis([0,1]); % Add color key
  xlabel('X'); ylabel('Z'); zlabel('u(r,\theta)');
  tmpStr=sprintf('at t=%2.1f',t(it)); % Prepare title text
  title([{'u(r,\theta), r=(X^2+Z^2)^{0.5},\theta=arctan(Z/X)'}
  {tmpStr}]);
  view([0,90]); % Set azimuth and elevation
  %
  % Set file name with numeric increment
  file=sprintf('sphericalMov%d.png', 100+it);
  disp(sprintf('Saving image to file: %s', file));
  %
  % Save image file
  print( '-dpng', '-zbuffer', '-r100', file);
end