% File: inital_1.m
% From Chapter 1 - 'An Introduction to the Method of Lines', of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
%
%
% Extra file - not included in book!
%
function Z = inital_1(N, opt)

global D t0 tf xl xu
Z = zeros(N,1);
i = 1;


if opt == 1,        % Quarter sine - full domain
    D=0.1;
    t0=0.0;
    tf=1.0;
    xl=0.0;
    xu=1.0;
    for j=1:N,
        Z(j,i)=sin((pi/2.0)*(j-1)/(N-1));
        if Z(j,i) < 0,
            Z(j,i) = 0;
        end
    end
elseif opt == 2,    % Half sine - part domain
    D=0.1;
    t0=0.0;
    tf=1.0;
    xl=0.0;
    xu=1.0;
    A=1;B=-4;
    alpha=0.75;
    lambda=0.7;
    K=8/N;
    for j=1:N,
        Z(j,i)=0.25*exp(-(alpha*lambda)^2 * i/6)*(A*sin(lambda*j*K) + B*cos(lambda*j*K));
        if Z(j,i) < 0,
            Z(j,i) = 0;
        end
    end
elseif opt == 3,    % Triangle - part domain
    D=0.05;
    t0=0.0;
    tf=1.0;
    xl=0.0;
    xu=1.0;
    A=0.3; B=0.5; C=0.7;  
    for j=1:N,
        x = j/N;
        if j < N/2,
            Z(j,i)= (x-A)/(B-A);
        else
            Z(j,i)= (C-x)/(C-B);
        end
        if Z(j,i) < 0,
            Z(j,i) = 0;
        end
    end
elseif opt == 4,    % Twin triangle - part domain
    D=0.05;
    t0=0.0;
    tf=1.0;
    xl=0.0;
    xu=1.0;
    A=0.1; B=0.3; C=0.5;  
    for j=1:N,
        x = j/N;
        if j < N/4
            Z(j,i)= (x-A)/(B-A);
        elseif j < N/2,
            Z(j,i)= (C-x)/(C-B);
        elseif j < 3*N/4,
            Z(j,i)= (x-A-0.4)/(B-A);
        else
            Z(j,i)= (C-x+0.4)/(C-B);
        end
        if Z(j,i) < 0
            Z(j,i) = 0;
        end
    end
elseif opt == 5,    % Step - part domain
    D=0.05;
    t0=0.0;
    tf=1.0;
    xl=0.0;
    xu=1.0;
    A=0.3; B=0.5; C=0.7;  
    for j=1:N,
        x = j/N;
        if x < A || x > C,
            Z(j,i)= 0;
        else
            Z(j,i)= 1;
        end
        if Z(j,i) < 0,
            Z(j,i) = 0;
        end
    end
elseif opt == 6,    % two node - whole domain 
    D=0.025;
    t0=0.0;
    tf=1.0;
    xl=0.0;
    xu=1.0;
    L=1;
    for j=1:N,
        x = (j-1)/(N-1);
        Z(j,i)=40*x*(L-x)*(x-0.45)^2;
        if Z(j,i) < 0,
            Z(j,i) = 0;
        end
    end
elseif opt == 7,    % two node - whole domain 
    D=1;
    t0=0;
    tf=1;
    xl=-5.0;
    xu= 5.0;
    for j=1:N,
        x = 5*(2*(j-1)/(N-1)-1);
        Z(j,i)=0.5*exp(-(x-1)^2) + exp(-(x+2)^2);
        if Z(j,i) < 0,
            Z(j,i) = 0;
        end
    end
elseif opt == 8,    % One node - whole domain 
    D=0.25;
    a=0.1;
    xl=0.0;
    xu=1.0;
    for j=1:N,
        x = (j-1)/(N-1);
        Z(j,i)=exp(-x^2/a^2);
        if Z(j,i) < 0,
            Z(j,i) = 0;
        end
    end
end







