% File: pde_1_main.m
% From Chapter 1 - 'An Introduction to the Method of Lines', of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
%
% Extra file - not included in book!
%
% Clear previous files
  clear all
  clf
  global D t0 tf xl xu
% Initial conditions
  n=41;
  initOpt = 7;  % 1 = Quarter sine - full domain
                % 2 = Half sine - part domain
                % 3 = Triangle - part domain
                % 4 = Twin triangle - part domain
                % 5 = Step - part domain
                % 6 = Two node - whole domain (ver 1)
                % 7 = Two node - whole domain (ver 2)
                % 8 = One node - whole domain
  initStr = [{'Quarter sine - full domain'}, ...
             {'Half sine - part domain'}, ...
             {'Triangle - part domain'}, ...
             {'Twin triangle - part domain'}, ...
             {'Step - part domain'}, ...
             {'Two node - whole domain, ver 1'}, ...
             {'Two node - whole domain, ver 2'}, ...
             {'One node - whole domain'}];
  
  u0=inital_1(n,initOpt);

  nout=n;
  h_t=(tf-t0)/(nout-1);
  tout=[t0:h_t:tf]';
%
% ODE integration
  reltol=1.0e-04; abstol=1.0e-04;
  options=odeset('RelTol',reltol,'AbsTol',abstol);
  [t,u]=ode45(@pde_1,tout,u0,options);   

% Display selected output
  n2=ceil((n-1)/2.0 + 1);
  fprintf('\n     t       u(x=0,t)\n');
  for i=1:5:nout
    fprintf('%6.3f%15.6f\n', t(i),u(i,n2));
  end
  
%  plot the numerical solution

figure(1);
colormap('Gray');
% colormap('copper');
C=ones(n);
% g=linspace(n,1,n);
g=linspace(-5,5,n);
h1 = waterfall(t,g,u',C); 
axis('tight');
grid off
view(310,55)
rotate3d on;

xlabel('t, time')
ylabel('x, space')
zlabel('MOL solution')
s1 = sprintf('Diffusion Equation - Method of Lines solution');
sTmp = char(initStr(1,initOpt));
s2 = sprintf('Initial condition: %s', sTmp);
title([{s1}, {s2}]);
set(gca,'YDir','reverse')
hold on

%   print -dpng -r300 pde6.png
prtAnal=1;
if initOpt==7 && prtAnal ==1
    N=4*n;
    tt=linspace(1,0,N);
    for i=1:N
        for j=1:N   
          x(j) = 5*(2*(j-1)/(N-1)-1);
          ua(i,j)=0.5*(exp(3*(2.*x(j)+1)/(4*tt(i)+1))+2) ...
                      /(4*tt(i)+1)^(1/2)*exp(-(x(j)+2)^2/(4.*tt(i)+1));    
        end     
    end

    figure(2);
    colormap('Gray');
    C=ones(n);
    gg=linspace(xl,xu,N); 
    h2 = surf(tt,gg,ua'); 
    shading interp
    axis('tight');
    grid off
    view(310,55)
    rotate3d on;

    xlabel('t, time')
    ylabel('x, space')
    zlabel('MOL solution')
    s1 = sprintf('Diffusion Equation - Method of Lines solution');
    sTmp = char(initStr(1,initOpt));
    s2 = sprintf('Initial condition: %s', sTmp);
    % s2 = sprintf('Initial condition');
    title([{s1}, {s2}]);
end











