% File: pde_1.m
% From Chapter 4 - 'Two Nonnlinear, Variable-Coefficient, Inhomogeneous
%                   Partial differential Equations', of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
%
  function yt=pde_1(t,y)
%
% Function pde_1 defines the ODEs in the MOL solution of two
% nonlinear PDEs
%
  global ncall   ncase...
             u       v...
            ut      vt...
            ux     uxx      vx     vxx...
             n       x      e4    ndss
%
% One vector to two vectors
  for i=1:n
    u(i)=y(i);
    v(i)=y(i+n);
  end
%
% Boundary conditions at x = 0
  u(1)=1.0;
  ut(1)=0.0;
  v(1)=1.0;
  vt(1)=0.0;
%
% First order spatial derivatives
  xl=x(1);
  xu=x(n);
%
% Three point centered differences
  if(ncase==1)ux=dss002(xl,xu,n,u); end   
  if(ncase==1)vx=dss002(xl,xu,n,v); end
%
% Five point centered differences
  if(ncase==2)ux=dss004(xl,xu,n,u); end
  if(ncase==2)vx=dss004(xl,xu,n,v); end
%
% Boundary conditions at x = 1
  ux(n)=3.0-3.0*u(n);
  vx(n)=e4*(u(n)-1.0)/5.0;
%
% Second order spatial derivatives
%
% Three point centered  differences
  if(ncase==1)vxx=dss002(xl,xu,n,vx); end
%
% Five point centered differences
  if(ncase==2)vxx=dss004(xl,xu,n,vx); end
%
% Array vx is used as temporary storage in the calculation
% of the term ((v - 1)*u )  which is finally stored in
% array uxx             x x
  for i=1:n
    vx(i)=(v(i)-1.0)*ux(i);
  end
  if(ncase==1)uxx=dss002(xl,xu,n,vx); end
  if(ncase==2)uxx=dss004(xl,xu,n,vx); end
%
% Two PDEs
  for i=2:n
    ex=exp(-4.0*x(i));
      ut(i)=uxx(i)+(16.0*x(i)*t-2.0*t-16.0*(v(i)-1.0))*(u(i)-1.0)+10.*x(i)*ex;
      vt(i)=vxx(i)+ux(i)+4.0*u(i)-4.0+x(i)^2-2.0*t-10.0*t*ex;
  end
%
% Two vectors to one vector
  for i=1:n
    yt(i)   =ut(i);
    yt(i+n) =vt(i);
  end
  yt=yt';
%
% Increment calls to pde_1
  ncall=ncall+1;
