% File: pde_1_main.m
% From Chapter 4 - 'Two Nonnlinear, Variable-Coefficient, Inhomogeneous
%                   Partial differential Equations', of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
%
% Clear previous files
  clear all
  clc
%
% Parameters shared with other routines
  global ncall   ncase...
             n       x    ndss
%
% Two cases: ncase = 1, second order finite differences
%
%            ncase = 2, fourth order finite difference
%
  for ncase=1:2
%
%   Initial condition
    n=41;
    t0=0.0;
%    y0=inital_1(t0);
    inital_1;
%
%   Independent variable for ODE integration
    tf=1.0; 
    nout=21;
    tout=linspace(t0,tf,nout);
    ncall=0;
%
%   ODE integration ;
    reltol=1.0e-04; abstol=1.0e-04;
    options=odeset('RelTol',reltol,'AbsTol',abstol);
    if(ncase==1) ndss=2; % ndss = 2, 4, 6, 8 or 10 required
      [t,y]=ode15s(@pde_1,tout,y0,options); end
    if(ncase==2) ndss=4; % ndss = 2, 4, 6, 8 or 10 required
      [t,y]=ode15s(@pde_1,tout,y0,options); end
%
%   One vector to two vectors
    for it=1:nout
    for i=1:n
      u(it,i)=y(it,i);
      v(it,i)=y(it,i+n);
    end
    end
%
%   Display a heading for the numerical and analytical solutions  
    fprintf('\n\n  ncase = %2d\n',ncase);
    fprintf('\n  u =  numerical u(x,t)');    
    fprintf('\n ua = analytical u(x,t)');
    fprintf('\n diff u = u - ua');
    fprintf('\n  v =  numerical v(x,t)');
    fprintf('\n va = analytical v(x,t)');
    fprintf('\n diff v = v - uv\n');
%
%   Analytical solutions, differences between these solutions at
%   selected x
    for it=1:nout
      fprintf('\n    t        x        u       ua      diff u');
      fprintf('\n                      v       va      diff v');
    for i=1:10:n
      ua(i)=1.0+10.0*x(i)*t(it)*exp(-4.0*x(i));
      du(i)=u(it,i)-ua(i);
      va(i)=1.0+(x(i)^2)*t(it);
      dv(i)=v(it,i)-va(i);
%
%   Display the numerical solutions, analytical solutions, differences
%   between the solutions
    fprintf('\n %4.2f%9.3f%9.4f%9.4f%12.2e\n%23.4f%9.4f%12.2e\n',...
            t(it),x(i),u(it,i),ua(i),du(i),v(it,i),va(i),dv(i));
    end
    end
    fprintf('  ncall = %5d\n',ncall);
%
% Plot solutions
  if(ncase==1)
%
%   Parametric plots
    figure(1);
    subplot(1,2,1)
    plot(x,u,'-k'); axis tight
    title('u(x,t) vs x, t = 0, 0.05, 0.1, ..., 1.0'); xlabel('x'); ylabel('u(x,t)')
    subplot(1,2,2)
    plot(x,v,'-k'); axis tight
    title('v(x,t) vs x, t = 0, 0.05, 0.1, ..., 1.0'); xlabel('x'); ylabel('v(x,t)')
%
%   Surface plots
    figure(2);
    surf(u); axis tight
    xlabel('x grid number');
    ylabel('t grid number');
    zlabel('u(x,t)');
    title('Two nonlinear PDEs');
    view([-115 36]);
    colormap gray
    rotate3d on; 
    figure(3);
    surf(v); axis tight
    xlabel('x grid number');
    ylabel('t grid number');
    zlabel('v(x,t)');
    title('Two nonlinear PDEs');
    view([170 24]);
    colormap gray
    rotate3d on;  
%   print -r300 -deps pde.eps; print -r300 -dps pde.ps; print -r300 -dpng pde.png    
  end
%  
% Next case
  end
