% File: phi.m
% From Chapter 5 - 'Euler, Navier Stokes and Burgers Equations', 
%                   of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function ua=phi(x,t)
%
% Funtion phi computes the exact solution of Burgers' equation
% for comparison with the numerical solution.  It is also used to
% define the initial and boundary conditions for the numerical 
% solution.
%
  global vis
%
% Analytical solution
  a=(0.05/vis)*(x-0.5+4.95*t);
  b=(0.25/vis)*(x-0.5+0.75*t);
  c=( 0.5/vis)*(x-0.375);
  ea=exp(-a);
  eb=exp(-b);
  ec=exp(-c);
  ua=(0.1*ea+0.5*eb+ec)/(ea+eb+ec);
