% File: inital_1.m
% From Chapter 6 - 'The Cubic Schrodinger Equation' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function u0=inital_1(t0)
%
% Function inital_1 sets the initial condition for the CSE
%
  global ncall     q     x     xl     xu   rt2     n
%
% q in cubic Schrodinger equation (CSE)
  q=1.0;
%
% Precompute 2^0.5
  rt2=sqrt(2.0);
%
% Grid spacing
  dx=(xu-xl)/(n-1);
%
% IC over the spatial grid
  for i=1:n
%
%   Uniform grid
    x(i)=xl+(i-1)*dx;
%
%   Initial real, imaginary parts (v(x,0), w(x,0)), absolute value 
%   of u(x,0) = u0(x) = (2^0.5)exp(0.5*i*x)sech(x), i = (-1)^0.5
%   over xl <= x <= xu
%
%   sech(x)
    sch=2.0/(exp(x(i))+exp(-x(i)));
%
%   Real part
    v(i)=rt2*cos(0.5*x(i))*sch;
%
%   Imaginary part
    w(i)=rt2*sin(0.5*x(i))*sch;
  end
%
% Two vectors to one vector
  for i=1:n
    u0(i)  =v(i);
    u0(i+n)=w(i);
  end