% File: pde_1.m
% From Chapter 6 - 'The Cubic Schrodinger Equation' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function ut=pde_1(t,u)
%
% Function yt computes the t derivative vector of the CSE
%
  global  ncall      q     xl     xu      n
%
% One vector to two vectors
  for i=1:n
    v(i)=u(i);
    w(i)=u(i+n);
  end  
%
% PDEs
%
%   v
%    xx
%
  vx=zeros(n,1);
  v(1)=0.0;
  v(n)=0.0;
  nl=1;
  nu=1;
  vxx=dss044(xl,xu,n,v,vx,nl,nu); 
%
%   w
%    xx
  wx=zeros(n,1);
  w(1)=0.0;
  w(n)=0.0;
  nl=1;
  nu=1;
  wxx=dss044(xl,xu,n,w,wx,nl,nu);
%
% ODEs at the boundaries
  vt(1)=0.0;
  wt(1)=0.0;
  vt(n)=0.0;
  wt(n)=0.0;
%
% ODEs at the interior points
  for i=2:n-1
%
%   v**2 + w**2
    v2w2(i)=v(i)^2+w(i)^2;
%
%   vt
    vt(i)=-wxx(i)-q*v2w2(i)*w(i);
%
%   wt
    wt(i)= vxx(i)+q*v2w2(i)*v(i);
  end
%
% Two vectors to one vector
  for i=1:n
    ut(i)  =vt(i);
    ut(i+n)=wt(i);
  end  
  ut=ut';
%
% Increment calls to pde_1
  ncall=ncall+1;
