% File: simp.m
% From Chapter 6 - 'The Cubic Schrodinger Equation' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function uint=simp(xl,xu,n,u)
%
% Function simp computes three integral invariants by Simpson's 
% rule
%
  global q
%  
% One vector to two vectors
  for i=1:n
    v(i)=u(i);
    w(i)=u(i+n);
  end
%
% Three invariants
  for int=1:3
    h=(xu-xl)/(n-1); 
%
%   I1
    if(int==1)
       uabs(1)=u(1)^2+v(1)^2; 
       uabs(n)=u(n)^2+v(n)^2;        
       uint(1)=uabs(1)-uabs(n); 
       for i=3:2:n
         uabs(i-1)=u(i-1)^2+v(i-1)^2;           
         uabs(i  )=u(i  )^2+v(i  )^2;  
         uint(1)=uint(1)+4.0*uabs(i-1)+2.0*uabs(i);  
       end
       uint(1)=h/3.0*uint(1);
    end 
%
%   I2
    if(int==2)       
       vx=dss004(xl,xu,n,v);
       wx=dss004(xl,xu,n,w);
       int(1)=v(1)*wx(1)-w(1)*vx(1); 
       int(n)=v(n)*wx(n)-w(n)*vx(n);
       uint(2)=int(1)-int(n);
       for i=3:2:n
         int(i-1)=v(i-1)*wx(i-1)-w(i-1)*vx(i-1); 
         int(i  )=v(i  )*wx(i  )-w(i  )*vx(i  );
         uint(2)=uint(2)+4.0*int(i-1)+2.0*int(i);  
       end
       uint(2)=h/3.0*uint(2);
    end   
%
%   I3
    if(int==3)
       uxabs(1)=vx(1)^2+wx(1)^2;
       uxabs(n)=vx(n)^2+wx(n)^2;
       uint(3)=uxabs(1)-0.5*q*uabs(1)^2-(uxabs(n)-0.5*q*uabs(n)^2); 
       for i=3:2:n
         uxabs(i-1)=vx(i-1)^2+wx(i-1)^2;
         uxabs(i)  =vx(i  )^2+wx(i  )^2;
         uint(3)=uint(3)+4.0*(uxabs(i-1)-0.5*q*uabs(i-1)^2)...
                        +2.0*(uxabs(i  )-0.5*q*uabs(i  )^2);  
       end
       uint(3)=2.0*h/3.0*uint(3);
    end       
  end    
