% File: inital_1.m
% From Chapter 7 - 'The Korteweg-de Vries Equation' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function u0=inital_1(t0)
%
% Function inital_1 sets the initial condition for the KdV equation
%
  global  ncase     c    c1    c2    xl    xu     x     n
%
% Spatial domain and initial condition
  xl=-30.0;
  xu= 70.0;
  dx=(xu-xl)/(n-1);
%
% Case 1 - single pulse
  if(ncase==1)
    for i=1:n
      x(i)=-30.0+(i-1)*dx;
      u0(i)=ua(x(i),0.0);
    end
  end 
%
% Case 2 - two pulses
  if(ncase==2)
    for i=1:n
      x(i)=-30.0+(i-1)*dx;
      expm=exp(-1.0/2.0*sqrt(c1)*(x(i)+15.0));
      expp=exp( 1.0/2.0*sqrt(c1)*(x(i)+15.0)); 
      pulse1=(1.0/2.0)*c1*(2.0/(expp+expm))^2;  
      expm=exp(-1.0/2.0*sqrt(c2)*(x(i)-15.0));
      expp=exp( 1.0/2.0*sqrt(c2)*(x(i)-15.0)); 
      pulse2=(1.0/2.0)*c2*(2.0/(expp+expm))^2;      
      u0(i)=pulse1+pulse2;
    end
  end    
   
