% File: simp.m
% From Chapter 7 - 'The Korteweg-de Vries Equation' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function uint=simp(xl,xu,n,u)
%
% Function simp computes three integral invariants by Simpson's 
% rule
%
  for int=1:3
    h=(xu-xl)/(n-1); 
%
%   Conservation of mass
    if(int==1)  
       uint(1)=u(1)-u(n); 
       for i=3:2:n
         uint(1)=uint(1)+4.0*u(i-1)+2.0*u(i);  
       end
       uint(1)=h/3.0*uint(1);
    end 
%
%   Conservation of energy
    if(int==2)  
       uint(2)=u(1)^2-u(n)^2; 
       for i=3:2:n
         uint(2)=uint(2)+4.0*u(i-1)^2+2.0*u(i)^2;  
       end
       uint(2)=(1.0/2.0)*h/3.0*uint(2);
    end   
%
%   Whitham conservation
    if(int==3)
       ux=dss004(xl,xu,n,u); 
       uint(3)=2.0*u(1)^3-ux(1)^2-(2.0*u(n)^3-ux(n)^2); 
       for i=3:2:n
         uint(3)=uint(3)+4.0*(2.0*u(i-1)^3-ux(i-1)^2)...
                        +2.0*(2.0*u(i)^3  -ux(i)^2);  
       end
       uint(3)=h/3.0*uint(3);
    end       
  end    