% File: uxxx7c.m
% From Chapter 7 - 'The Korteweg-de Vries Equation' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function uxxx=uxxx7c(xl,xu,n,u)
%
% Function uxxx7c computes the derivative uxxx in the KdV equation
%
% Spatial increment
  dx=(xu-xl)/(n-1);
  r8dx3=1.0/(8.0*(dx^3));
%
% uxxx
  for i=1:n
%
%   At the left end, uxxx = 0
    if(i<4)uxxx(i)=0.0; 
%
%   At the right end, uxxx = 0
    elseif(i>(n-3))uxxx(i)=0.0; 
%
%   Interior points
    else
    uxxx(i)=r8dx3*...
       (   1.0*u(i-3)... 
          -8.0*u(i-2)...
         +13.0*u(i-1)...
          +0.0*u(i  )...
         -13.0*u(i+1)...
          +8.0*u(i+2)...
          -1.0*u(i+3));
    end
  end  
 