% A one-dimensional Particle Physics Equation is
%
%   utt = uxx -lambda*u^3 + m^2*u
%
% Clear previous files
  clear all
  clc %
%  
% Parameters shared with the ODE routine
  global  ncall ncase  ndss   x    xl    xu     n
  global  c1 c2 lambda m 
%
% Boundaries, number of grid points
  xl=-30.0;
  xu= 30.0;
  n=201;
%
% Initial condition 
  t0=0.0;
  u0=inital_1(t0);
%
% Independent variable for ODE integration
  tf=10.0;
  tout=[t0,tf]';
  ncall=0;
%
% ODE integration
  reltol=1.0e-06; abstol=1.0e-06;
  options=odeset('RelTol',reltol,'AbsTol',abstol);
  ndss=42; % ndss = 42, 44, 46, 48 or 50 required 
  [t,u]=ode45(@pde_3,tout,u0,options);
%
% One vector to two vectors
  nt=length(t);
  for it=1:nt
    for i=1:n
      u1(it,i)=u(it,i);
      u2(it,i)=u(it,i+n);
    end  
  end  
%
% Plot numerical and analytical solutions
  figure()
  surf(x,t,u1)
  shading 'interp'
  xlabel('x')
  ylabel('t');
  zlabel('u')
  title('Particle Physics equation')
  %print -deps -r300 pde.eps; print -dps -r300 pde.ps; print -dpng -r300 pde.png
%





