% File: pde_1_main.m
% From Chapter 8 - 'The Linear Wave Equation' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
%
% The one-dimensional wave equation is
%
%   utt = c^2*uxx
%
% where c is the velocity of the wave.
%
% If initial conditions are specified as
%
%   u(x,t=0) = f(x)
%
%   ut(x,t=0) = 0
%
% the d'Alembert analytical solution is
%
%   u(x,t) = f(x - c*t) + f(x + c*t)
%
% This analytical solution is used to test the numerical solution.
%
% Clear previous files
  clear all
  clc %
%  
% Parameters shared with the ODE routine
  global  ncall ncase  ndss     c     x    xl    xu     n
  c=1.0; 
  global  c1 c2 lambda m x01 x02
%
% Boundaries, number of grid points
  xl=-30.0;
  xu=30.0;
  n=201;
%
% Initial condition 
  t0=0.0;
  ncase=4;
  lambda=1;m=1/2;
  c1= 1/2;x01= 20;
  c2=-1/2;x02=-20;
  u0=inital_2(t0);
%
% Independent variable for ODE integration
  tf=40.0;
  tout=[t0,tf]';
  ncall=0;
%
% ODE integration 
  mf=3;
  reltol=1.0e-06; abstol=1.0e-06;
  options=odeset('RelTol',reltol,'AbsTol',abstol);
  if(mf==1) ndss=0; % explicit FDs 
    [t,u]=ode45(@pde_1,tout,u0,options); end 
  if(mf==2) ndss=4; % ndss = 2, 4, 6, 8 or 10 required
    [t,u]=ode45(@pde_2,tout,u0,options); end
  if(mf==3) ndss=44; % ndss = 42, 44, 46, 48 or 50 required 
    [t,u]=ode45(@pde_3,tout,u0,options); end
%
% One vector to two vectors
  nt=length(t);
  for it=1:nt
  for i=1:n
    u1(it,i)=u(it,i);
    u2(it,i)=u(it,i+n);
  end  
  end  
%
% Display selected output
  fprintf('  ncall = %4d\n\n',ncall);
%
% Plot numerical and analytical solutions
  figure()
  surf(x,t,u1) 
  shading 'interp'
  xlabel('x')
  ylabel('t')
  zlabel('u(x,t)')
  title('Particle Physics equation')
%


