% File: pde_3.m
% From Chapter 8 - 'The Linear Wave Equation' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function ut=pde_3(t,u)
%
% Function pde_3 computes the t derivative vector for the wave equation
%
  global  ncall  ndss     c    xl    xu     n
  global  c1 c2 lambda m

%
% One vector to two vectors
  for i=1:n
    u1(i)=u(i);
    u2(i)=u(i+n);
  end
%
% Calculate u1xx with ux(1) = ux(n) = 0 as BCs
  u1x=zeros(n,1);
  u1x(1)=0.0;
  u1x(n)=0.0;
  nl=2;
  nu=2;
  if    (ndss==42), u1xx=dss042(xl,xu,n,u1,u1x,nl,nu); % second order  
  elseif(ndss==44), u1xx=dss044(xl,xu,n,u1,u1x,nl,nu); % fourth order
  elseif(ndss==46), u1xx=dss046(xl,xu,n,u1,u1x,nl,nu); % sixth order
  elseif(ndss==48), u1xx=dss048(xl,xu,n,u1,u1x,nl,nu); % eighth order      
  elseif(ndss==50), u1xx=dss050(xl,xu,n,u1,u1x,nl,nu); % tenth order
  end 
%
% PDE
  cs=c^2;
  u1t=zeros(1,n);u2t=u1t;
% size(u1xx)
% size(u1)
% size(u2)
% size(u2t)
  for i=1:n
    u1t(1,i)=u2(1,i);  
    u2t(1,i)=u1xx(1,i)-lambda*u1(1,i)^3+ m^2*u1(1,i);
  end
%
% Two vectors to one vector
  for i=1:n
    ut(i)  =u1t(i);
    ut(i+n)=u2t(i);
  end 
  ut(1)=0;
  ut(n)=0; 
  ut=ut';
%
% Increment calls to pde_3
  ncall=ncall+1;

