% File: ua.m
% From Chapter 8 - 'The Linear Wave Equation' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function uanal=ua(t,x)
%
% Function ua computes the analytical solution to the wave
% equation
%
  global  ncall ncase  ndss     c    xl    xu     n  
  global  c1 c2 lambda m
%
% The following coding is specific to the interval 0 le x le 100
%
% Rectangular pulse
  if(ncase==1)
    for i=1:n
      if     x(i)<(45.0-c*t)  pulse1(i)=0.0; 
      elseif x(i)>(55.0-c*t)  pulse1(i)=0.0;
      elseif x(i)>=(45.0-c*t) & x(i)<=(50.0-c*t)...
             pulse1(i)=0.5;
      elseif x(i)>=(50.0-c*t) & x(i)<=(55.0-c*t)...
             pulse1(i)=0.5;   
      end
      if     x(i)<(45.0+c*t)  pulse2(i)=0.0; 
      elseif x(i)>(55.0+c*t)  pulse2(i)=0.0;
      elseif x(i)>=(45.0+c*t) & x(i)<=(50.0+c*t)...
             pulse2(i)=0.5;
      elseif x(i)>=(50.0+c*t) & x(i)<=(55.0+c*t)...
             pulse2(i)=0.5;   
      end
      uanal(i)=pulse1(i)+pulse2(i);
    end 
  end  
%
% Triangular pulse
  if(ncase==2)
    for i=1:n
      if     x(i)<(45.0-c*t)  pulse1(i)=0.0; 
      elseif x(i)>(55.0-c*t)  pulse1(i)=0.0;
      elseif x(i)>=(45.0-c*t) & x(i)<=(50.0-c*t)...
             pulse1(i)=(x(i)-(45.0-c*t))/10.0;
      elseif x(i)>=(50.0-c*t) & x(i)<=(55.0-c*t)...
             pulse1(i)=((55.0-c*t)-x(i))/10.0;   
      end
      if     x(i)<(45.0+c*t)  pulse2(i)=0.0; 
      elseif x(i)>(55.0+c*t)  pulse2(i)=0.0;
      elseif x(i)>=(45.0+c*t) & x(i)<=(50.0+c*t)...
             pulse2(i)=(x(i)-(45.0+c*t))/10.0;
      elseif x(i)>=(50.0+c*t) & x(i)<=(55.0+c*t)...
             pulse2(i)=((55.0+c*t)-x(i))/10.0;   
      end
      uanal(i)=pulse1(i)+pulse2(i);
    end 
  end  
%
% Sine pulse
  if(ncase==3)
    for i=1:n      
      if     x(i)<(45.0-c*t)  pulse1(i)=0.0; 
      elseif x(i)>(55.0-c*t)  pulse1(i)=0.0;
      elseif x(i)>=(45.0-c*t) & x(i)<=(50.0-c*t)...
             pulse1(i)=(1.0/2.0)*sin(pi*(x(i)-(45.0-c*t))/10.0);
      elseif x(i)>=(50.0-c*t) & x(i)<=(55.0-c*t)...
             pulse1(i)=(1.0/2.0)*sin(pi*((55.0-c*t)-x(i))/10.0);   
      end
      if     x(i)<(45.0+c*t)  pulse2(i)=0.0; 
      elseif x(i)>(55.0+c*t)  pulse2(i)=0.0;
      elseif x(i)>=(45.0+c*t) & x(i)<=(50.0+c*t)...
             pulse2(i)=(1.0/2.0)*sin(pi*(x(i)-(45.0+c*t))/10.0);
      elseif x(i)>=(50.0+c*t) & x(i)<=(55.0+c*t)...
             pulse2(i)=(1.0/2.0)*sin(pi*((55.0+c*t)-x(i))/10.0);  
      end
      uanal(i)=pulse1(i)+pulse2(i);
    end 
  end  
%
% Gaussian pulse
  if(ncase==4)
    a=2.0;
    for i=1:n      
      if     x(i)<(45.0-c*t)  pulse1(i)=0.0; 
      elseif x(i)>(55.0-c*t)  pulse1(i)=0.0;
      elseif x(i)>=(45.0-c*t) & x(i)<=(55.0-c*t)...
             pulse1(i)=(1.0/2.0)*exp(-a*(x(i)-(50.0-c*t))^2/10.0);
      end
      if     x(i)<(45.0+c*t)  pulse2(i)=0.0; 
      elseif x(i)>(55.0+c*t)  pulse2(i)=0.0;
      elseif x(i)>=(45.0+c*t) & x(i)<=(55.0+c*t)...
             pulse2(i)=(1.0/2.0)*exp(-a*(x(i)-(50.0+c*t))^2/10.0);
      end
      uanal(i)=pulse1(i)+pulse2(i);
    end     
  end