% File: pde_1_main.m
% From Chapter 8 - 'The Linear Wave Equation' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
%
% The one-dimensional wave equation is
%
%   utt = c^2*uxx
%
% where c is the velocity of the wave.
%
% If initial conditions are specified as
%
%   u(x,t=0) = f(x)
%
%   ut(x,t=0) = 0
%
% the d'Alembert analytical solution is
%
%   u(x,t) = f(x - c*t) + f(x + c*t)
%
% This analytical solution is used to test the numerical solution.
%
% Clear previous files
  clear all
  clc %
%  
% Parameters shared with the ODE routine
  global  ncall ncase  ndss     c     x    xl    xu     n
  c=1.0;  
%
% Select case
%
%   Case 1 - rectangular pulse
%
%   Case 2 - triangular pulse
%
%   Case 3 - sine pulse
%
%   Case 4 - Gaussian pulse
%
  for ncase=4:4
%
% Boundaries, number of grid points
  xl=0.0;
  xu=100.0;
  n=401;
%
% Initial condition 
  t0=0.0;
  u0=inital_1(t0);
%
% Independent variable for ODE integration
  tf=30.0;
  tout=[t0:10.0:tf]';
  nout=4;
  ncall=0;
%
% ODE integration 
  mf=3;
  reltol=1.0e-04; abstol=1.0e-04;
  options=odeset('RelTol',reltol,'AbsTol',abstol);
  if(mf==1) ndss=0; % explicit FDs 
    [t,u]=ode45(@pde_1,tout,u0,options); end 
  if(mf==2) ndss=4; % ndss = 2, 4, 6, 8 or 10 required
    [t,u]=ode45(@pde_2,tout,u0,options); end
  if(mf==3) ndss=44; % ndss = 42, 44, 46, 48 or 50 required 
    [t,u]=ode45(@pde_3,tout,u0,options); end
%
% One vector to two vectors
  for it=1:nout
  for i=1:n
    u1(it,i)=u(it,i);
    u2(it,i)=u(it,i+n);
  end  
  end  
%
% Display selected output
  fprintf('\n   ncase = %2d,   c = %2d\n\n',ncase,c);
  for it=1:nout
    fprintf('     t       x         u(i,j)    u_anal(i,j)       err(i,j)\n');
    u_anal(it,:)=ua(t(it),x);
    for i=1:10:n 
      err(it,i)=u1(it,i)-u_anal(it,i);
      fprintf('%6.2f%8.3f%15.6f%15.6f%15.6f\n',...
            t(it),x(i),u1(it,i),u_anal(it,i),err(it,i));
    end
    fprintf('\n');
  end
  fprintf('  ncall = %4d\n\n',ncall);
%
% Plot numerical and analytical solutions
  figure(ncase)
  plot(x,u1,'o',x,u_anal,'-')
  xlabel('x')
  ylabel('u(x,t)')
  title('Wave equation; t = 0, 10, 20, 30; o - numerical; solid - analytical')
  print -deps -r300 pde.eps; print -dps -r300 pde.ps; print -dpng -r300 pde.png
%
% Next case
  end

