% File: pde_1_main.m
% From Chapter 9 - 'Maxwell's equations' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
%
% Clear previous files
  clear all
  clc %
%  
% Parameters shared with the ODE routine
  global  ncall ndss c1 c2 xl xu n  
%
% Select case
%
%   Case 1 - second order FDs
%
%   Case 2 - fourth order FDs
%
%   Case 3 - sixth order FDs
%
  for ncase=1:3
%
% Problem parameters
  eps=1.0;
  mu=1.0;
  sigma=1.0;
  c1=sigma/eps;
  c2=1.0/(mu*eps);
%
% Boundaries, number of grid points
  xl=0.0;
  xu=1.0;
  n=101;
%
% Initial condition 
  t0=0.0;
  dx=(xu-xl)/(n-1);
  for i=1:n
    x(i)=xl+(i-1)*dx;
    u0(i)=cos(pi*x(i));
    u0(i+n)=0.0;
  end  
%
% Independent variable for ODE integration
  tf=1.0;
  tout=[t0:0.2:tf]';
  nout=6;
  ncall=0;
%
% ODE integration 
  reltol=1.0e-04; abstol=1.0e-04;
  options=odeset('RelTol',reltol,'AbsTol',abstol);
  if    (ncase==1) ndss=42; 
  elseif(ncase==2) ndss=44;
  elseif(ncase==3) ndss=46; end
%
% Implicit (sparse stiff) integration
  S=jpattern_num;
  pause
  options=odeset(options,'JPattern',S)
  [t,u]=ode15s(@pde_1,tout,u0,options);   
%
% One vector to two vectors
  for it=1:nout
  for i=1:n
    u1(it,i)=u(it,i);
    u2(it,i)=u(it,i+n);
  end  
  end  
%
% Display selected output
  fprintf('\n  ncase = %2d  ndss = %2d  c1 = %4.2f  c2 = %4.2f\n\n',...
          ncase,ndss,c1,c2);
  for it=1:nout
    fprintf('     t       x         u(x,t)        ut(x,t)\n');
    for i=1:10:n 
      fprintf('%6.2f%8.3f%15.6f%15.6f\n',t(it),x(i),u1(it,i),u2(it,i));
    end
    fprintf('\n');
  end
  fprintf('  ncall = %4d\n\n',ncall);
%
% Plot numerical solution
  figure(ncase)
  plot(x,u1,'-')
  xlabel('x')
  ylabel('u(x,t)')
  title('Maxwell`s equation; t = 0, 0.2,... 1.0')
% print -deps -r300 pde.eps; print -dps -r300 pde.ps; print -dpng -r300 pde.png
%
% Next case
  end

