% File: pde_2.m
% From Chapter 10 - 'Elliptic Partial Differential Equations: Laplace's
%                   Equation' of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function yt=pde_2(t,y)
%
% Function pde_2 computes the temporal derivative in the pseudo transient
% solution of Laplace's equation by stagewise differentiation
%
%
% Problem parameters
  global ncall nx ny ndss mmf
  xl=0.0;
  xu=1.0;
  yl=0.0;
  yu=1.0;
%
% 1D to 2D matrix conversion
  if(mmf==1)
    for i=1:nx
    for j=1:ny
      u(i,j)=y((i-1)*ny+j);
    end
    end
  end
  if(mmf==2)
    u=reshape(y,ny,nx)';
  end
%
% PDE
%
% ux
  for j=1:ny
    u1d=u(:,j);  
    if    (ndss== 2) ux1d=dss002(xl,xu,nx,u1d); % second order  
    elseif(ndss== 4) ux1d=dss004(xl,xu,nx,u1d); % fourth order
    elseif(ndss== 6) ux1d=dss006(xl,xu,nx,u1d); % sixth order
    elseif(ndss== 8) ux1d=dss008(xl,xu,nx,u1d); % eighth order      
    elseif(ndss==10) ux1d=dss010(xl,xu,nx,u1d); % tenth order
    end 
%   
% uxx
    ux1d(1) =0.0;
    ux1d(nx)=0.0;
    if    (ndss== 2) uxx1d=dss002(xl,xu,nx,ux1d); % second order  
    elseif(ndss== 4) uxx1d=dss004(xl,xu,nx,ux1d); % fourth order
    elseif(ndss== 6) uxx1d=dss006(xl,xu,nx,ux1d); % sixth order
    elseif(ndss== 8) uxx1d=dss008(xl,xu,nx,ux1d); % eighth order      
    elseif(ndss==10) uxx1d=dss010(xl,xu,nx,ux1d); % tenth order
    end
%
% 1D to 2D    
    uxx(:,j)=uxx1d(:);
  end 
%
% uy
  for i=1:nx
    u1d=u(i,:);  
    if    (ndss== 2) uy1d=dss002(yl,yu,ny,u1d); % second order  
    elseif(ndss== 4) uy1d=dss004(yl,yu,ny,u1d); % fourth order
    elseif(ndss== 6) uy1d=dss006(yl,yu,ny,u1d); % sixth order
    elseif(ndss== 8) uy1d=dss008(yl,yu,ny,u1d); % eighth order      
    elseif(ndss==10) uy1d=dss010(yl,yu,ny,u1d); % tenth order
    end 
%   
% uyy
    if    (ndss== 2) uyy1d=dss002(yl,yu,ny,uy1d); % second order  
    elseif(ndss== 4) uyy1d=dss004(yl,yu,ny,uy1d); % fourth order
    elseif(ndss== 6) uyy1d=dss006(yl,yu,ny,uy1d); % sixth order
    elseif(ndss== 8) uyy1d=dss008(yl,yu,ny,uy1d); % eighth order      
    elseif(ndss==10) uyy1d=dss010(yl,yu,ny,uy1d); % tenth order
    end
%
% 1D to 2D
    uyy(i,:)=uyy1d(:);
  end
%
% ut = uxx + uyy
  ut=uxx+uyy;
  ut(:,1) =0.0;
  ut(:,ny)=0.0;
%
% 2D to 1D matrix conversion
  if(mmf==1)
    for i=1:nx
    for j=1:ny
      yt((i-1)*ny+j)=ut(i,j);  
    end
    end
    yt=yt';
  end
  if(mmf==2)
    yt=reshape(ut',nx*ny,1);
  end
%
% Increment calls to pde_2
  ncall=ncall+1;
