% File: pde_1.m
% From Chapter 11 - 'Tree-Dimensional Partial Differential Equation',
%                    of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function yt=pde_1(t,y)
%
% Function pde_1 computes the temporal derivative in the pseudo transient
% solution of Laplace's equation by explicit finite differences
%
% Problem parameters
  global ncall nx ny mmf
  xl=0.0;
  xu=1.0;
  yl=0.0;
  yu=1.0;
%
% Initially zero derivatives in x, y, t
  uxx=zeros(nx,ny); uyy=zeros(nx,ny); ut=zeros(nx,ny);
%
% 1D to 2D matrix conversion
  if(mmf==1)
    for i=1:nx
    for j=1:ny
      u(i,j)=y((i-1)*ny+j);
    end
    end
  end
  if(mmf==2)
    u=reshape(y,ny,nx)';
  end
%
% PDE
  dx2=((xu-xl)/(nx-1))^2;
  dy2=((yu-yl)/(ny-1))^2;
  for i=1:nx
  for j=1:ny 
%
%   uxx
    if(i==1)      uxx(i,j)=2.0*(u(i+1,j)-u(i,j))/dx2;
    elseif(i==nx) uxx(i,j)=2.0*(u(i-1,j)-u(i,j))/dx2;
    else          uxx(i,j)=(u(i+1,j)-2.0*u(i,j)+u(i-1,j))/dx2;    
    end 
%
%   uyy
    if(j~=1)&(j~=ny)uyy(i,j)=(u(i,j+1)-2.0*u(i,j)+u(i,j-1))/dy2; end         
%
%   ut = uxx + uyy
    if(j==1)|(j==ny)ut(i,j)=0.0; 
    else ut(i,j)=uxx(i,j)+uyy(i,j);
    end
  end      
  end
%
% 2D to 1D matrix conversion
  if(mmf==1)
    for i=1:nx
    for j=1:ny
      yt((i-1)*ny+j)=ut(i,j);  
    end
    end
    yt=yt';
  end
  if(mmf==2)
    yt=reshape(ut',nx*ny,1);
  end
%
% Increment calls to pde_1
  ncall=ncall+1;

  
