% File: pde_3.m
% From Chapter 11 - 'Tree-Dimensional Partial Differential Equation',
%                    of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function yt=pde_3(t,y)
%
% Function pde_3 computes the temporal derivative in the pseudo transient
% solution of Laplace's equation by library routines for the second derivative
%
% Problem parameters
  global ncall nx ny ndss mmf
  xl=0.0;
  xu=1.0;
  yl=0.0;
  yu=1.0;
%
% 1D to 2D matrix conversion
  if(mmf==1)
    for i=1:nx
    for j=1:ny
      u(i,j)=y((i-1)*ny+j);
    end
    end
  end
  if(mmf==2)
    u=reshape(y,ny,nx)';
  end
%
% PDE
%
% uxx
  for j=1:ny
    u1d=u(:,j); 
    nl=2; % Neumann
    nu=2; % Neumann
    ux1d(1) =0.0;
    ux1d(nx)=0.0;
    if    (ndss==42) uxx1d=dss042(xl,xu,nx,u1d,ux1d,nl,nu); % second order
    elseif(ndss==44) uxx1d=dss044(xl,xu,nx,u1d,ux1d,nl,nu); % fourth order
    elseif(ndss==46) uxx1d=dss046(xl,xu,nx,u1d,ux1d,nl,nu); % sixth order
    elseif(ndss==48) uxx1d=dss048(xl,xu,nx,u1d,ux1d,nl,nu); % eighth order      
    elseif(ndss==50) uxx1d=dss050(xl,xu,nx,u1d,ux1d,nl,nu); % tenth order
    end    
%
% 1D to 2D    
    uxx(:,j)=uxx1d(:);
  end 
%
% uyy
  for i=1:nx
    u1d=u(i,:); 
    nl=1; % Dirichlet
    nu=1; % Dirichlet
    uy1d(:)=0.0;
    if    (ndss==42) uyy1d=dss042(yl,yu,ny,u1d,uy1d,nl,nu); % second order
    elseif(ndss==44) uyy1d=dss044(yl,yu,ny,u1d,uy1d,nl,nu); % fourth order
    elseif(ndss==46) uyy1d=dss046(yl,yu,ny,u1d,uy1d,nl,nu); % sixth order
    elseif(ndss==48) uyy1d=dss048(yl,yu,ny,u1d,uy1d,nl,nu); % eighth order      
    elseif(ndss==50) uyy1d=dss050(yl,yu,ny,u1d,uy1d,nl,nu); % tenth order
    end    
%
% 1D to 2D
    uyy(i,:)=uyy1d(:);
  end
%
% ut = uxx + uyy
  ut=uxx+uyy;
  ut(:,1) =0.0;
  ut(:,ny)=0.0;
%
% 2D to 1D matrix conversion
  if(mmf==1)
    for i=1:nx
    for j=1:ny
      yt((i-1)*ny+j)=ut(i,j);  
    end
    end
    yt=yt';
  end
  if(mmf==2)
    yt=reshape(ut',nx*ny,1);
  end
%
% Increment calls to pde_3
  ncall=ncall+1;
