% File: pde_1.m
% From Chapter 13 - 'Simultaneous, Nonlinear, Two-Dimensional Partial
%                    Differential Equations in Cylindrical Coordinates',
%                    of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function yt=pde_1(t,y)
%
% Global area
  global     nr     nz     dr     dz    drs    dzs...
              r     r0      z     zl     Dc     Dt...
             ca     Tk    cae    Tke      h      k...
              E      R    rk0      v    rho     Cp...
             Tw     dH  ncall  
%
% 1D to 2D matrices
  for i=1:nz
  for j=1:nr
    ij=(i-1)*nr+j;
    ca(i,j)=y(ij);
    Tk(i,j)=y(ij+nr*nz);
  end
  end
%
% Step through the grid points in r and z
  for i=1:nz
  for j=1:nr  
%
%   (1/r)*car, (1/r)*Tkr
    if(j==1)
      car(i,j)=2.0*(ca(i,j+1)-ca(i,j))/drs;
      Tkr(i,j)=2.0*(Tk(i,j+1)-Tk(i,j))/drs;
    elseif(j==nr)
      car(i,j)=0.0;
      Tkr(i,j)=(1.0/r(j))*(h/k)*(Tw-Tk(i,j));
    else
      car(i,j)=(1.0/r(j))*(ca(i,j+1)-ca(i,j-1))/(2.0*dr);
      Tkr(i,j)=(1.0/r(j))*(Tk(i,j+1)-Tk(i,j-1))/(2.0*dr);
    end      
%
%   carr, Tkrr
    if(j==1)
      carr(i,j)=2.0*(ca(i,j+1)-ca(i,j))/drs;
      Tkrr(i,j)=2.0*(Tk(i,j+1)-Tk(i,j))/drs;
    elseif(j==nr)
      carr(i,j)=2.0*(ca(i,j-1)-ca(i,j))/drs;
      Tkf=Tk(i,j-1)+2.0*dr*h/k*(Tw-Tk(i,j));
      Tkrr(i,j)=(Tkf-2.0*Tk(i,j)+Tk(i,j-1))/drs;
    else
      carr(i,j)=(ca(i,j+1)-2.0*ca(i,j)+ca(i,j-1))/drs;
      Tkrr(i,j)=(Tk(i,j+1)-2.0*Tk(i,j)+Tk(i,j-1))/drs;
    end
%
%   caz, Tkz
    if(i==1)  
      caz(i,j)=(ca(i,j)-cae)/dz;
      Tkz(i,j)=(Tk(i,j)-Tke)/dz;
    else 
      caz(i,j)=(ca(i,j)-ca(i-1,j))/dz;
      Tkz(i,j)=(Tk(i,j)-Tk(i-1,j))/dz;
    end        
%
%   PDEs
      rk=rk0*exp(-E/(R*Tk(i,j)))*ca(i,j)^2;
      cat(i,j)=Dc*(carr(i,j)+car(i,j))-v*caz(i,j)-rk;
      Tkt(i,j)=Dt*(Tkrr(i,j)+Tkr(i,j))-v*Tkz(i,j)...
              -dH/(rho*Cp)*rk;
  end
  end
%
% 2D to 1D matrices
  for i=1:nz
  for j=1:nr
    ij=(i-1)*nr+j;
    yt(ij)=cat(i,j);
    yt(ij+nr*nz)=Tkt(i,j);
  end
  end 
%
% Transpose and count
  yt=yt';
  ncall=ncall+1;