% File: pde_2.m
% From Chapter 13 - 'Simultaneous, Nonlinear, Two-Dimensional Partial
%                    Differential Equations in Cylindrical Coordinates',
%                    of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function yt=pde_2(t,y)
%
% Global area
  global     nr     nz     dr     dz    drs    dzs...
              r     r0      z     zl     Dc     Dt...
             ca     Tk    cae    Tke      h      k...
              E      R    rk0      v    rho     Cp...
             Tw     dH  ncall  
%
% 1D to 2D matrices
  for i=1:nz
  for j=1:nr
    ij=(i-1)*nr+j;
    ca(i,j)=y(ij);
    Tk(i,j)=y(ij+nr*nz);
  end
  end
%
% Step through the grid points in r and z
  for i=1:nz
    ca1d=ca(i,:);  
    Tk1d=Tk(i,:);      
%
%   car, Tkr
    car1d=dss004(0.0,r0,nr,ca1d);
    car(i,:)=car1d;
    car(i,1)= 0.0;
    car(i,nr)=0.0;
    Tkr1d=dss004(0.0,r0,nr,Tk1d);
    Tkr(i,:)=Tkr1d;
    Tkr(i,1)= 0.0;
    Tkr(i,nr)=(h/k)*(Tw-Tk(i,nr));
%
%   carr, Tkrr
    car1d( 1)=0.0;
    car1d(nr)=0.0;
    nl=2;
    nu=2;
    carr1d=dss044(0.0,r0,nr,ca1d,car1d,nl,nu);
    carr(i,:)=carr1d;
    Tkr1d( 1)=0.0;
    Tkr1d(nr)=(h/k)*(Tw-Tk1d(nr));
    nl=2;
    nu=2;
    Tkrr1d=dss044(0.0,r0,nr,Tk1d,Tkr1d,nl,nu);
    Tkrr(i,:)=Tkrr1d; 
  for j=1:nr 
%
%   (1/r)*car, (1/r)*Tkr
    if(j~=1)
      car(i,j)=(1.0/r(j))*car(i,j);
      Tkr(i,j)=(1.0/r(j))*Tkr(i,j);
    end  
    if(j==1)carr(i,j)=2.0*carr(i,j);end
    if(j==1)Tkrr(i,j)=2.0*Tkrr(i,j);end
%
%   caz, Tkz
    if(i==1)  
      caz(i,j)=(ca(i,j)-cae)/dz;
      Tkz(i,j)=(Tk(i,j)-Tke)/dz;
    else 
      caz(i,j)=(ca(i,j)-ca(i-1,j))/dz;
      Tkz(i,j)=(Tk(i,j)-Tk(i-1,j))/dz;
    end        
%
%   PDEs
      rk=rk0*exp(-E/(R*Tk(i,j)))*ca(i,j)^2;
      cat(i,j)=Dc*(carr(i,j)+car(i,j))-v*caz(i,j)-rk;
      Tkt(i,j)=Dt*(Tkrr(i,j)+Tkr(i,j))-v*Tkz(i,j)...
              -dH/(rho*Cp)*rk;
  end
  end
%
% 2D to 1D matrices
  for i=1:nz
  for j=1:nr
    ij=(i-1)*nr+j;
    yt(ij)=cat(i,j);
    yt(ij+nr*nz)=Tkt(i,j);
  end
  end 
%
% Transpose and count
  yt=yt';
  ncall=ncall+1;