% File: pde_2.m (rev. 1 - October 2012)
% From Chapter 14 - 'Diffusion Equation in Spherical Coordinates',
%                    of the book:
% William E Schiesser and Graham W Griffiths (2009).
% A Compendium of Partial Differential Equation Models
% - Method of Lines Analysis with Matlab,
% Cambridge University Press (ISBN-13: 9780521519861).
  function yt=pde_2(t,y)
%
% Global area
  global r r0 nr th th0 nth D std_0 std_pi2 f tau ncall
%
% Preallocate arrays
u=zeros(nr,nth);
ur=zeros(nr,nth);
urr=zeros(nr,nth);
uth=zeros(nr,nth);
uthth=zeros(nr,nth);
ut=zeros(nr,nth);
yt=zeros(1,nr*nth);
%
% 1D to 2D
  for i=1:nr
  for j=1:nth 
    u(i,j)=y((i-1)*nth+j);  
  end
  end
%
% Spatial grids in r and theta
  for i=1:nr
  for j=1:nth      
%
%   ur
    u1d=u(:,j);
    ur1d=dss004(0.0,r0,nr,u1d);
    ur1d(nr)=0.0;
    ur1d( 1)=0.0;        
    ur(:,j)=ur1d;
%
%   urr
    urr1d=dss004(0.0,r0,nr,ur1d);
    urr(:,j)=urr1d;
%    
%   uth
    u2d=u(i,:);
    uth1d=dss004(0.0,th0,nth,u2d);
    uth1d(nth)=0.0;
    uth1d(  1)=0.0;        
    uth(i,:)=uth1d;
%
%   uthth
    uthth1d=dss004(0.0,th0,nth,uth1d);
    uthth(i,:)=uthth1d;
  end
  end
%
% Inhomogeneous term
  if(t<=tau)
    fs=f;  
  else    
    fs=0*f;
  end 
%
% PDE
  for i=1:nr
  for j=1:nth
%   r=0
    if(i==1)
%     PDE for r = 0
      ut(i,j)=D*(urr(i,j)+2.0*urr(i,j))+fs(i,j);
%
%   r ~= 0
    else %if(i~=1)
%     PDEs for r ~= 0
      if(j==1) %||j==nth)
%     th = 0, pi/2    
        ut(i,j)=D*(urr(i,j)+(2.0/r(i))*ur(i,j)...
               +(2.0/r(i)^2)*uthth(i,j))+fs(i,j);     
      else
%       th ~= 0, pi/2
        ut(i,j)=D*(urr(i,j)+(2.0/r(i))*ur(i,j)...
             +(1.0/r(i)^2)*(uthth(i,j)+(cos(th(j))/sin(th(j)))*uth(i,j)))+fs(i,j);
      end
    end
  end
  end
%
% 2D to 1D
  for i=1:nr
  for j=1:nth
    yt((i-1)*nth+j)=ut(i,j);  
  end
  end
  yt=yt';
%
% Increment number of calls to pde_2
  ncall=ncall+1;
